@@ -45,13 +45,13 @@ TerminalPainter::TerminalPainter(TerminalDisplay *parent)
 {
 }
 
-static inline bool isLineCharString(const QString &string)
+static inline bool isLineCharString(const QString &string, bool braille)
 {
     if (string.length() == 0) {
         return false;
     }
     if (LineBlockCharacters::canDraw(string.at(0).unicode())) {
-        return true;
+        return !(braille && LineBlockCharacters::isBraille(string.at(0).unicode()));
     }
     if (string.length() <= 1 || !string[0].isSurrogate()) {
         return false;
@@ -596,6 +596,7 @@ void TerminalPainter::drawCursor(QPainter &painter, const QRect &rect, const QCo
     QColor cursorColor = color.isValid() ? color : foregroundColor;
 
     QPen pen(cursorColor);
+    pen.setJoinStyle(Qt::MiterJoin);
     // TODO: the relative pen width to draw the cursor is a bit hacky
     // and set to 1/12 of the font width. Visually it seems to work at
     // all scales but there must be better ways to do it
@@ -605,6 +606,7 @@ void TerminalPainter::drawCursor(QPainter &painter, const QRect &rect, const QCo
     painter.setPen(pen);
 
     if (m_parentDisplay->cursorShape() == Enum::BlockCursor) {
+        painter.setRenderHint(QPainter::Antialiasing, true);
         if (m_parentDisplay->hasFocus()) {
             painter.fillRect(cursorRect, cursorColor);
 
@@ -614,6 +616,7 @@ void TerminalPainter::drawCursor(QPainter &painter, const QRect &rect, const QCo
             // it is drawn entirely inside cursorRect
             painter.drawRect(cursorRect.adjusted(halfWidth, halfWidth, -halfWidth, -halfWidth));
         }
+        painter.setRenderHint(QPainter::Antialiasing, false);
     } else if (m_parentDisplay->cursorShape() == Enum::UnderlineCursor) {
         QLineF line(cursorRect.left() + halfWidth, cursorRect.bottom() - halfWidth, cursorRect.right() - halfWidth, cursorRect.bottom() - halfWidth);
         painter.drawLine(line);
@@ -689,7 +692,7 @@ void TerminalPainter::drawCharacters(QPainter &painter,
         painter.setPen(color);
     }
     // draw text
-    if (isLineCharString(text) && !m_parentDisplay->terminalFont()->useFontLineCharacters()) {
+    if (!m_parentDisplay->terminalFont()->useFontLineCharacters() && isLineCharString(text, m_parentDisplay->terminalFont()->useFontBrailleCharacters())) {
         int y = rect.y();
 
         if (lineProperty.flags.f.doubleheight_bottom) {
@@ -1122,7 +1125,7 @@ void TerminalPainter::drawTextCharacters(QPainter &painter,
     // const auto origClipRegion = painter.clipRegion();
     // painter.setClipRect(rect);
     // draw text
-    if (isLineCharString(text) && !m_parentDisplay->terminalFont()->useFontLineCharacters()) {
+    if (!m_parentDisplay->terminalFont()->useFontLineCharacters() && isLineCharString(text, m_parentDisplay->terminalFont()->useFontBrailleCharacters())) {
         int y = rect.y();
 
         if (lineProperty.flags.f.doubleheight_bottom) {
